﻿//The Command Menu where the player creates the command for the dog.

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CommandMenu : MonoBehaviour {

	public string clicked = " ";
	public bool inUse = false;

	public GameObject[] Lines;
	public GameObject Arrow;
	public GameObject SideBar;
	public GameObject Camera;
	public GameObject NumberMenu;
	public GameObject LeapMenu;

	private bool arrowSet = false;
	private int modifier = -1;
	private int currentSlot = 0;
	private int[,] CommandTable = new int[10, 2];
	private bool subMenu = false;
	private bool numberMenu = false;
	private bool walk = false;
	private float startY;

	// Use this for initialization
	void Start () {
		startY = transform.position.y;
		ResetTable ();
	}
	
	// Update is called once per frame
	void Update () {
		if (inUse) {
			//Draw the Command menu with the proper values
			arrowSet = false;
			for (int i = 0; i < Lines.GetLength (0); i++) {
				string word = "bla";
				switch (CommandTable [i, 0]) {
				case -1:
					word = "______";
					if (!arrowSet) {
						Arrow.transform.position = new Vector3 (Arrow.transform.position.x, Lines [i].transform.position.y, Arrow.transform.position.z);
						arrowSet = true;
					}
					break;
				case 0:
					word = "Walk(" + CommandTable [i,1] + ");";
					break;
				case 1:
					word = "Run(" + CommandTable [i,1] + ");";
					break;
				case 2:
					string otherWord = "aaaaa";
					if (CommandTable [i,1] == 0)
						otherWord = "Up";
					else
						otherWord = "Right";
					word = "Leap(" + otherWord + ");";
					break;
				case 3:
					word = "Stay();";
					break;
				case 4:
					word = "Bite();";	//FOR DEBUG PURPOSES ONLY
					break;
				}

				Lines [i].GetComponent<TextMesh> ().text = word;
			}

			if (!subMenu) {
				//Check for clicked command addition
				if (clicked != " ") {
					if (clicked == "Walk") {
						subMenu = true;
						numberMenu = true;
						walk = true;
						NumberMenu.transform.GetChild (0).GetComponent<TextMesh> ().text = clicked;
					} else if (clicked == "Run") {
						subMenu = true;
						numberMenu = true;
						walk = false;
						NumberMenu.transform.GetChild (0).GetComponent<TextMesh> ().text = clicked;
					} else if (clicked == "Leap") {
						subMenu = true;
						numberMenu = false;
					} else if (clicked == "Go") {
						CommandReady ();
					} else {
						AddToTable ();
					}
				}
			} else {	//SubMenu Update
				if (numberMenu) {
					NumberMenu.transform.position = new Vector3 (Camera.transform.position.x + 5.5f, Camera.transform.position.y+1.5f, 
						NumberMenu.transform.position.z);

					if (clicked == "Plus") {
						int newInt = System.Convert.ToInt32(NumberMenu.transform.GetChild (1).GetComponent<TextMesh> ().text);
						newInt++;
						NumberMenu.transform.GetChild (1).GetComponent<TextMesh> ().text = newInt.ToString();
						clicked = " ";
					} else if (clicked == "Minus") {
						int newInt = System.Convert.ToInt32(NumberMenu.transform.GetChild (1).GetComponent<TextMesh> ().text);
						newInt--;
						NumberMenu.transform.GetChild (1).GetComponent<TextMesh> ().text = newInt.ToString();
						clicked = " ";
					} else if (clicked == "Ok") {
						int newInt = System.Convert.ToInt32(NumberMenu.transform.GetChild (1).GetComponent<TextMesh> ().text);
						modifier = newInt;
						if (walk)
							clicked = "Walk";
						else
							clicked = "Run";
						AddToTable ();
					}
				} else {
					LeapMenu.transform.position = new Vector3 (Camera.transform.position.x + 5f, Camera.transform.position.y+1.5f, 
						LeapMenu.transform.position.z);

					if (clicked == "Up") {
						modifier = 0;
						clicked = "Leap";
						AddToTable ();
					} else if (clicked == "Right") {
						modifier = 1;
						clicked = "Leap";
						AddToTable ();
					}
				}
			}

			if (Input.GetKeyDown (KeyCode.Escape)) {	//Clear and Close
				if (!subMenu) {
					ResetTable ();
					MoveWindow ();
				} else {
					MoveSubWindow ();
				}
			}

			if (Input.GetKeyDown (KeyCode.Backspace)) {	//Remove last input command
				if (!subMenu) {
					if (currentSlot > 0) {
						CommandTable [currentSlot, 0] = -1;
						CommandTable [currentSlot, 1] = -1;
						currentSlot--;
					}
				} else {
					MoveSubWindow ();
				}
			}
		}
	}

	void AddToTable(){	//Place current command into table
		int primary = -1;
		switch (clicked) {
		case "Walk":
			primary = 0;
			break;
		case "Run":
			primary = 1;
			break;
		case "Leap":
			primary = 2;
			break;
		case "Stay":
			primary = 3;
			break;
		case "Bite":
			primary = 4;
			break;
		}

		clicked = " ";
		CommandTable [currentSlot, 0] = primary;
		CommandTable [currentSlot, 1] = modifier;
		currentSlot++;

		if (subMenu)
			MoveSubWindow ();
	}

	void ResetTable(){	//Clear table to all -1 values
		for (int i = 0; i < CommandTable.GetLength (0); i++) {
			for (int j = 0; j < CommandTable.GetLength (1); j++) {
				CommandTable [i, j] = -1;
			}
		}
	}

	void CommandReady(){	//Activate command
		for (int i = 0; i < CommandTable.GetLength (0); i++) {
			for (int j = 0; j < CommandTable.GetLength (1); j++) {
				GameObject.FindGameObjectWithTag ("Dog").GetComponent<Dog> ().CommandTable[i,j] = CommandTable[i,j];
			}
		}
		GameObject.FindGameObjectWithTag ("Dog").GetComponent<Dog> ().command = true;
		ResetTable ();

		GameObject.FindGameObjectWithTag ("Player").GetComponent<Player> ().CommandEnded ();
		MoveWindow ();
	}

	public void MoveWindow(){	//Move window into view or hide
		if (inUse) {
			transform.position = new Vector3 (Camera.transform.position.x, 100, transform.position.z);
			SideBar.transform.position = new Vector3 (Camera.transform.position.x, 100, transform.position.y);
			inUse = false;
			clicked = " ";
			currentSlot = 0;
			GameObject.FindGameObjectWithTag ("Player").GetComponent<Player> ().inMenu = false;
		} else {
			transform.position = new Vector3 (Camera.transform.position.x - 5, Camera.transform.position.y, transform.position.z);
			SideBar.transform.position = new Vector3 (transform.position.x+5.25f, transform.position.y, transform.position.z);
			inUse = true;
		}
	}

	void MoveSubWindow(){
		subMenu = false;
		NumberMenu.transform.position = new Vector3 (NumberMenu.transform.position.x, 100, NumberMenu.transform.position.z);
		LeapMenu.transform.position = new Vector3 (NumberMenu.transform.position.x, 100, LeapMenu.transform.position.z);
		clicked = " ";
		walk = false;
	}
}
