﻿//Controls all Dog physics and internal commands of the Dog

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Dog : MonoBehaviour {

	public bool follow = false;
	public bool following = false;

	private GameObject Player;
	private Rigidbody2D rigi;

	//Command Variables
	public bool command = false;
	public int[,] CommandTable = new int[10,2];	//First slot Command number, 2nd Variable number
	private int commandCounter = 0;
	private int commandLim = 50;
	private int currentCommand = 0;
	private bool commandStarted = false;	//Used for specific commands, like applying leap vertical physics one time
	private float commandLeapVerY = 700;
	private float commandLeapHorY = 450;
	private float leapSpeed = 1f;

	//Movement Variables
	private float walkSpeed = .3f;
	private float runMaxSpeed = 8f;
	private float runSpeed = .55f;
	private float speedAdditive = 1.6f;
	private float speedDecriment = 1.2f;
	private float jumpForce = 500;

	private int jumpCounter = 100;
	private int jumpLimit = 70;

	public bool bite = false; //FOR TESTING PURPOSES ONLY

	// Use this for initialization
	void Start () {
		rigi = GetComponent<Rigidbody2D> ();
		Player = GameObject.FindGameObjectWithTag ("Player");
	}

	void FixedUpdate(){
		if (!command) {
			if (follow && following) {
				float move = 0;
				if (Player.transform.position.x > transform.position.x) {
					move = runSpeed;
				} else {
					move = -runSpeed;
				}

				float rigiMove = rigi.velocity.x + (move * speedAdditive);
				if (rigiMove > runMaxSpeed)
					rigiMove = runMaxSpeed;
				else if (rigiMove < -runMaxSpeed)
					rigiMove = -runMaxSpeed;

				rigi.velocity = new Vector2 ((rigiMove / speedDecriment), rigi.velocity.y);
			} else {
				rigi.velocity = new Vector2 ((rigi.velocity.x / speedDecriment), rigi.velocity.y);
			}
		}
	}

	// Update is called once per frame
	void Update () {
		if (!command) {	//General player following routine
			if (follow && following) {
				Vector3 right = transform.TransformDirection (Vector3.right) * 1;
				Vector3 left = transform.TransformDirection (Vector3.left) * 1;
				//Debug.DrawRay (transform.position, forward, Color.green);

				if (jumpCounter > 0)
					jumpCounter--;

				//If following player and a wall is in the way, jump over it
				RaycastHit2D hit;
				if (rigi.velocity.x > 0) {
					hit = Physics2D.Raycast (transform.position, right, 1f, -1, 0);
				} else {
					hit = Physics2D.Raycast (transform.position, left, 1f, -1, 0);
				}
				if (hit.collider != null && jumpCounter == 0) {
					rigi.AddForce (new Vector2 (0, jumpForce));
					jumpCounter = jumpLimit;
				}
			}
		} else {	//Performing a command
			switch (CommandTable [currentCommand, 0]) {
			case -1:	//Empty command slot, command is finished
				command = false;
				ClearCommandTable ();
				break;
			case 0:		//Walk
				if (CommandTable [currentCommand, 1] > 0) {
					Walk ();
				} else {
					IncreaseCommandPos ();
				}
				break;
			case 1:		//Run
				if (CommandTable [currentCommand, 1] > 0) {
					Run ();
				} else {
					IncreaseCommandPos ();
				}
				break;
			case 2:		//Leap
				Leap (CommandTable[currentCommand,1]);
				break;
			case 3:		//Stay
				Stay();
				break;
			case 4:
				bite = true;	//FOR DEBUG PURPOSES ONLY
				break;
			}
		}
	}

	void OnTriggerEnter2D(Collider2D other)
	{
		if (other.tag == "Player") {
			following = false;
		} else if (other.tag == "Enemy") {	//FOR DEBUG PURPOSES ONLY!!
			if (bite)
				Destroy (other.gameObject);
		}
	}

	void OnTriggerStay2D(Collider2D other){
		if (other.tag == "Enemy") {
			if (bite)
				Destroy (other.gameObject);
		}
	}

	void OnTriggerExit2D(Collider2D other)
	{
		if (other.tag == "Player") {
			following = true;
		}
	}

	//Commands -------

	void Walk(){ //0 - # of moves
		commandCounter++;
		if (commandCounter < commandLim) {
			rigi.velocity = new Vector2 (runMaxSpeed/2f, rigi.velocity.y);
		} else {
			CommandTable [currentCommand, 1]--;
			commandCounter = 0;
		}
	}

	void Run(){	//1 - # of moves
		commandCounter++;
		if (commandCounter < commandLim) {
			rigi.velocity = new Vector2 (runMaxSpeed/1.5f, rigi.velocity.y);
		} else {
			CommandTable [currentCommand, 1]--;
			commandCounter = 0;
		}
	}

	void Leap(int direction){ //2 - 0 = Vertical leap, 1 = horizontal
		commandCounter++;
		if (commandCounter < commandLim) {
			if (direction == 0) {	//Vertical, high jump, low horizontal speed
				if (!commandStarted) {
					rigi.AddForce (new Vector2 (0, commandLeapVerY));
					commandStarted = true;
				}
				rigi.velocity = new Vector2 (walkSpeed + 1, rigi.velocity.y);
			} else {	//Horizontal, low jump, high horizontal speed
				if (!commandStarted) {
					rigi.AddForce (new Vector2 (0, commandLeapHorY));
					commandStarted = true;
				}
				rigi.velocity = new Vector2 (leapSpeed, rigi.velocity.y);
			}
		} else {
			currentCommand++;
		}
	}

	void Stay(){	//3 - Stops all following commands, removes Follow
		command = false;
		follow = false;
		following = false;
		ClearCommandTable ();
	}
		
	//General Command Operations -----
	public void ClearCommandTable(){	//Remove all commands in table
		command = false;
		commandCounter = 0;
		currentCommand = 0;
		for (int i = 0; i < CommandTable.GetLength (0); i++) {
			for (int j = 0; j < CommandTable.GetLength (1); j++) {
				CommandTable [i, j] = -1;
			}
		}
	}

	void IncreaseCommandPos(){	//Current command task is done, go to next
		commandCounter = 0;
		commandStarted = false;
		currentCommand++;
		if (currentCommand >= CommandTable.GetLength (0)) {
			command = false;
			ClearCommandTable ();
		}
	}
}
