﻿//Controls all player controls/physics

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Player : MonoBehaviour {

	public GameObject Whistle;
	public GameObject DogAttributes;

	public AudioClip Whistle2;

	//Physics Variables
	private Rigidbody2D rigi;
	private float runMaxSpeed = 7.5f;
	private float speedAdditive = 1.6f;
	private float speedDecriment = 1.2f;
	private float jumpForce = 95;

	//Ground Check Variables
	bool grounded = false;
	public Transform GroundCheck;
	float groundRadius = 0.2f;
	public LayerMask whatIsGround;

	//Logic Variables
	public bool inMenu = false;

	// Use this for initialization
	void Start () {
		rigi = GetComponent<Rigidbody2D> ();
	}

	void FixedUpdate(){
		//Check if on the ground
		grounded = Physics2D.OverlapCircle (GroundCheck.position, groundRadius, whatIsGround);

		//Control Horizontal and Vertical Movement
		float move = 0;
		if (!inMenu) {
			move = Input.GetAxis ("Horizontal");
		}

		float rigiMove = rigi.velocity.x + (move * speedAdditive);
		if (rigiMove > runMaxSpeed)
			rigiMove = runMaxSpeed;
		else if (rigiMove < -runMaxSpeed)
			rigiMove = -runMaxSpeed;

		rigi.velocity = new Vector2 ((rigiMove / speedDecriment), rigi.velocity.y);
	}
	
	// Update is called once per frame
	void Update () {
		if (!inMenu) {
			if (grounded) {		//Jump, only if touching the ground
				if (Input.GetKeyDown (KeyCode.UpArrow) || Input.GetKeyDown (KeyCode.Space) || Input.GetKeyDown (KeyCode.W)) {
					rigi.AddForce (new Vector2 (0, jumpForce));
				}
			}

			if (Input.GetKeyDown (KeyCode.E)) {	//Whistles to get dog's attention, dog follows player
				GameObject newWhistle = Instantiate (Whistle, new Vector3 (transform.position.x + 1.5f, transform.position.y + .5f, Whistle.transform.position.z),
					                       Quaternion.identity) as GameObject;
				newWhistle.GetComponentInChildren<TextMesh> ().text = "Follow();";
				newWhistle.transform.parent = transform;

				GameObject Dog = GameObject.FindGameObjectWithTag ("Dog");
				Dog.GetComponent<Dog> ().follow = true;
				Dog.GetComponent<Dog> ().following = true;
				Dog.GetComponent<Dog> ().ClearCommandTable ();
			}

			if (Input.GetKeyDown (KeyCode.C)) {	//Command Menu, set pseudoscript to tell dog what to do
				inMenu = true;
				GameObject CommandMenu = GameObject.FindGameObjectWithTag ("Command");	//FOR DEBUG PURPOSES ONLY
				CommandMenu.GetComponent<CommandMenu>().MoveWindow();
			}
		}
	}

	void OnTriggerStay2D(Collider2D other){		//When in attribute editing range
		if (other.gameObject.tag == "Dog" && !inMenu) {
			GameObject QM = other.transform.Find ("QuestionMark").gameObject;
			QM.SetActive (true);

			if (Input.GetKeyDown (KeyCode.Q)) {	//inMenu prevents player from accidently moving
				inMenu = true;
				DogAttributes.GetComponent<MenuScript> ().inUse = true;
				QM.SetActive (false);
			}
		}
	}

	void OnTriggerExit2D(Collider2D other){		//Leaving attribute editing range
		if (other.gameObject.tag == "Dog") {
			GameObject QM = other.transform.Find ("QuestionMark").gameObject;
			QM.SetActive (false);
		}
	}

	public void CommandEnded(){	//Whistle Command notification
		GameObject newWhistle = Instantiate (Whistle, new Vector3 (transform.position.x + 1.5f, transform.position.y + .5f, Whistle.transform.position.z),
			Quaternion.identity) as GameObject;
		newWhistle.GetComponent<AudioSource> ().Stop();
		newWhistle.GetComponent<AudioSource> ().PlayOneShot (Whistle2, 1);
		newWhistle.GetComponentInChildren<TextMesh> ().text = "Command();";
		newWhistle.GetComponentInChildren<TextMesh> ().fontSize = 18;
		newWhistle.transform.parent = transform;
	}
}
